@@ -126,6 +126,8 @@ const (
 	ArgClusterAutoscalerScaleDownUtilizationThreshold = "scale-down-utilization-threshold"
 	// ArgClusterAutoscalerScaleDownUnneededTime is the cluster autoscaler scale down unneeded time
 	ArgClusterAutoscalerScaleDownUnneededTime = "scale-down-unneeded-time"
+	// ArgEnableRoutingAgent enables the routing-agent cluster plugin.
+	ArgEnableRoutingAgent = "enable-routing-agent"
 	// ArgSurgeUpgrade is a cluster's surge-upgrade argument.
 	ArgSurgeUpgrade = "surge-upgrade"
 	// ArgCommandUpsert is an upsert for a resource to be created or updated argument.
@@ -523,6 +525,29 @@ const (
 	// ArgVPCPeeringVPCID is id of the VPC.
 	ArgVPCPeeringVPCID = "vpc-id"
 
+	// ArgInterconnectAttachmentType is the type of the Interconnect Attachment e.g. "partner".
+	ArgInterconnectAttachmentType = "type"
+	// ArgPartnerInterconnectAttachmentName is a name of the Partner Interconnect Attachment.
+	ArgPartnerInterconnectAttachmentName = "name"
+	// ArgPartnerInterconnectAttachmentConnectionBandwidthInMbps is the connection bandwidth in megabits per second.
+	ArgPartnerInterconnectAttachmentConnectionBandwidthInMbps = "connection-bandwidth-in-mbps"
+	// ArgPartnerInterconnectAttachmentRegion is the region slug.
+	ArgPartnerInterconnectAttachmentRegion = "region"
+	// ArgPartnerInterconnectAttachmentNaaSProvider is the name of the Network as a Service provider
+	ArgPartnerInterconnectAttachmentNaaSProvider = "naas-provider"
+	// ArgPartnerInterconnectAttachmentVPCIDs are the IDs of the VPCs which the Partner Interconnect Attachment is connected
+	ArgPartnerInterconnectAttachmentVPCIDs = "vpc-ids"
+	// ArgPartnerInterconnectAttachmentBGPLocalASN is the BGP Autonomous System Number (ASN) of the local device
+	ArgPartnerInterconnectAttachmentBGPLocalASN = "bgp-local-asn"
+	// ArgPartnerInterconnectAttachmentBGPLocalRouterIP is the BGP IP address of the local device
+	ArgPartnerInterconnectAttachmentBGPLocalRouterIP = "bgp-local-router-ip"
+	// ArgPartnerInterconnectAttachmentBGPPeerASN is the BGP Autonomous System Number (ASN) of the peer device
+	ArgPartnerInterconnectAttachmentBGPPeerASN = "bgp-peer-asn"
+	// ArgPartnerInterconnectAttachmentBGPPeerIPAddress is the BGP IP address of the peer device
+	ArgPartnerInterconnectAttachmentBGPPeerRouterIP = "bgp-peer-router-ip"
+	// ArgPartnerInterconnectAttachmentBGPAuthKey is the BGP MD5 authentication key
+	ArgPartnerInterconnectAttachmentBGPAuthKey = "bgp-auth-key"
+
 	// ArgReadWrite indicates a generated token should be read/write.
 	ArgReadWrite = "read-write"
 	// ArgRegistry indicates the name of the registry.
