@@ -5,8 +5,8 @@
 
 package tools
 
-//go:generate go install github.com/golang/mock/mockgen
+//go:generate go install go.uber.org/mock/mockgen
 
 import (
-	_ "github.com/golang/mock/mockgen"
+	_ "go.uber.org/mock/mockgen"
 )
